==> surefire-api-2.7.2-sources.jar: org/apache/maven/surefire/report/MulticastingReporter.java <==
package org.apache.maven.surefire.report;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Iterator;
import java.util.List;

/**
 * A reporter that broadcasts to other reporters
 *
 * @author Kristian Rosenvold
 */
public class MulticastingReporter
    implements Reporter, RunReporter, ReportWriter
{
    private final List target;

    public MulticastingReporter( List target )
    {
        this.target = target;
    }

    public void testSetStarting( ReportEntry report )
        throws ReporterException
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).testSetStarting( report );
        }
    }

    public void testSetCompleted( ReportEntry report )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            try
            {
                ( (ReportWriter) it.next() ).testSetCompleted( report );
            }
            catch ( ReporterException e )
            {
                // Added in commit r331325 in ReporterManager. This smells fishy. What's this about ?
            }

        }
    }


    public void runStarting()
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            Object next = it.next();
            if ( next instanceof RunReporter )
            {
                ( (RunReporter) next ).runStarting();
            }
        }
    }

    public void runCompleted()
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            Object next = it.next();
            if ( next instanceof RunReporter )
            {
                ( (RunReporter) next ).runCompleted();
            }
        }
    }


    public void testStarting( ReportEntry report )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).testStarting( report );
        }
    }

    public void testSucceeded( ReportEntry report )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).testSucceeded( report );
        }
    }

    public void testError( ReportEntry report, String stdOut, String stdErr )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).testError( report, stdOut, stdErr );
        }
    }

    public void testFailed( ReportEntry report, String stdOut, String stdErr )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).testFailed( report, stdOut, stdErr );
        }
    }

    public void testSkipped( ReportEntry report )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).testSkipped( report );
        }
    }

    public void writeConsoleMessage( String message )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ReportWriter reporter = ( (ReportWriter) it.next() );
            // Todo: Really need to find out how the surefire4.x provider manages to avoid printing to this one.
            if ( !( reporter instanceof BriefFileReporter ) )
            {
                reporter.writeMessage( message );
            }
        }
    }

    public void writeDetailMessage( String message )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ReportWriter reporter = ( (ReportWriter) it.next() );
            reporter.writeDetailMessage( message );
        }
    }

    public void writeMessage( String message )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).writeMessage( message );
        }
    }

    public void writeFooter( String footer )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).writeFooter( footer );
        }
    }

    public void reset()
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).reset();
        }
    }

    public void testError( ReportEntry report )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).testError( report );
        }
    }

    public void testFailed( ReportEntry report )
    {
        for ( Iterator it = target.iterator(); it.hasNext(); )
        {
            ( (ReportWriter) it.next() ).testFailed( report );
        }
    }

    public void testAssumptionFailure( ReportEntry report )
    {
        // Do nothing right now.
    }
}

==> surefire-api-2.10-sources.jar: org/apache/maven/surefire/report/MulticastingReporter.java <==
package org.apache.maven.surefire.report;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.List;

/**
 * A reporter that broadcasts to other reporters
 *
 * @author Kristian Rosenvold
 */
public class MulticastingReporter
    implements Reporter
{
    private final Reporter[] target;
    private final int size;

    public MulticastingReporter( List target )
    {
        size = target.size();
        this.target = (Reporter[]) target.toArray( new Reporter[target.size()] );
    }

    public void testSetStarting( ReportEntry report )
    {
        for (int i = 0; i < size; i++){
            target[i].testSetStarting( report );
        }
    }

    public void testSetCompleted( ReportEntry report )
    {
        for (int i = 0; i < size; i++){
            target[i].testSetCompleted( report );
        }
    }


    public void testStarting( ReportEntry report )
    {
        for (int i = 0; i < size; i++){
            target[i].testStarting( report );
        }
    }

    public void testSucceeded( ReportEntry report )
    {
        for (int i = 0; i < size; i++){
            target[i].testSucceeded( report );
        }
    }

    public void testError( ReportEntry report, String stdOut, String stdErr )
    {
        for (int i = 0; i < size; i++){
            target[i].testError( report, stdOut, stdErr );
        }
    }

    public void testFailed( ReportEntry report, String stdOut, String stdErr )
    {
        for (int i = 0; i < size; i++){
            target[i].testFailed( report, stdOut, stdErr );
        }
    }

    public void testSkipped( ReportEntry report )
    {
        for (int i = 0; i < size; i++){
            target[i].testSkipped( report );
        }
    }

    public void writeMessage( String message )
    {
        for (int i = 0; i < size; i++){
            target[i].writeMessage( message );
        }
    }

    public void writeMessage( byte[] b, int off, int len )
    {
        for (int i = 0; i < size; i++){
            target[i].writeMessage( b, off, len );
        }
    }

    public void reset()
    {
        for (int i = 0; i < size; i++){
            target[i].reset();
        }
    }

}
